@@ -19,7 +19,7 @@ cmake \
     -DCMAKE_BUILD_TYPE=Release \
     -DBUILD_SHARED_LIBS=ON \
     -DBUILD_STATIC_LIBS=OFF \
-    -DEXAMPLES_ENABLE=ON \
+    -DEXAMPLES_ENABLE_C=ON \
     -DEXAMPLES_INSTALL=OFF \
     -DOPENMP_ENABLE=$WITH_OPENMP \
     -DLAPACK_ENABLE=ON \
