@@ -1,8 +1,9 @@
 #!/bin/sh
 
-echo "project (my_sundials_test)">CMakeLists.txt
+echo "cmake_minimum_required(VERSION 2.8)" > CMakeLists.txt
+echo "project (my_sundials_test)" >> CMakeLists.txt
 echo "add_executable (cvRoberts_dns cvRoberts_dns.c)" >>CMakeLists.txt
-echo "target_link_libraries (cvRoberts_dns LINK_PUBLIC m sundials_cvode openblas sundials_nvecserial)" >>CMakeLists.txt
+echo "target_link_libraries (cvRoberts_dns LINK_PUBLIC sundials_cvode sundials_nvecserial)" >>CMakeLists.txt
 echo "enable_testing()" >>CMakeLists.txt
 echo "add_test (test_roberts cvRoberts_dns)" >>CMakeLists.txt
 
